/*-------------------------------------------------------------------------+
| Copyright 2023 fortiss GmbH                                              |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.tooling.ext.quality.ui.view.fx;

import org.eclipse.ui.part.ViewPart;
import org.fortiss.tooling.common.ui.javafx.AF3FXViewPart;

import javafx.scene.Scene;

/**
 * {@link ViewPart} for the FX implementation of the metrics view.
 *
 * @author groh
 */
public class MetricsFXViewPart extends AF3FXViewPart implements IMetricsViewPart {

	/** The FX Controller for this view. */
	private static final MetricsFXController VIEW_CONTROLLER = new MetricsFXController();

	/**
	 * Constructor.
	 *
	 * @throws Exception
	 */
	public MetricsFXViewPart() throws Exception {
		super(VIEW_CONTROLLER, null);
	}

	/**
	 * Returns the initialized {@link MetricsFXController} for the reuse
	 * version of the {@link AF3FXViewPart}.
	 *
	 * @return The view controller for the metrics view
	 */
	public static MetricsFXController getMetricsFXController() {
		return VIEW_CONTROLLER;
	}

	/** {@inheritDoc} */
	@Override
	protected Scene createFxScene() {
		Scene scene = super.createFxScene();

		getSite().getWorkbenchWindow().getSelectionService().addSelectionListener(VIEW_CONTROLLER);

		return scene;
	}

}
